.. image:: https://img.shields.io/pypi/v/jaraco.apt.svg
   :target: https://pypi.org/project/jaraco.apt

.. image:: https://img.shields.io/pypi/pyversions/jaraco.apt.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.apt/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.apt

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/jaraco-apt/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/jaraco-apt/branch/master

.. image:: https://readthedocs.org/projects/jaracoapt/badge/?version=latest
   :target: https://jaracoapt.readthedocs.io/en/latest/?badge=latest

Support module for `Debian APT <https://wiki.debian.org/Apt>`_.
